@@ -1,4 +1,6 @@
+## ----------------------------------------------------------------------------|
 # sampling from Wishart distribution
+## ----------------------------------------------------------------------------|
 rwish = function( n = 1, p = 2, b = 3, D = diag(p) )
 {
 	Ti      = chol( solve( D ) ) 
@@ -7,7 +9,7 @@ rwish = function( n = 1, p = 2, b = 3, D = diag(p) )
 	
 	for ( i in 1 : n )
 	{
-		result       = .C( "rwish", as.double(Ti), K = as.double(K), as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
+		result       = .C( "rwish_c", as.double(Ti), K = as.double(K), as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
 		samples[,,i] = matrix( result $ K, p, p ) 		
 	}	
 
