@@ -1,12 +1,13 @@
-#include <Rconfig.h>
-#ifdef SUPPORT_OPENMP
+#include "util.h"
+
+#ifdef _OPENMP
 #include <omp.h>
 #endif
 
 extern "C" {
 	void omp_set_num_cores( int *cores ) 
 	{
-		#ifdef SUPPORT_OPENMP
+		#ifdef _OPENMP
 			omp_set_num_threads( *cores );
 		#endif
 	}
